==> jc-1.4.0.tar.gz: jas/CodeAttributeDecoder.h <==
// class jas.CodeAttributeDecoder

// class file dependencies
// @dep_class 1e8dee4cc3706ae3 jas_CodeAttributeDecoder
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_jas_CodeAttributeDecoder_H_
#define _JC_jas_CodeAttributeDecoder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Hashtable$object;

// Typedefs
typedef struct _jc_jas_CodeAttributeDecoder$sub_refs	_jc_jas_CodeAttributeDecoder$sub_refs;
typedef struct _jc_jas_CodeAttributeDecoder$sub_nonrefs	_jc_jas_CodeAttributeDecoder$sub_nonrefs;
typedef struct _jc_jas_CodeAttributeDecoder$refs	_jc_jas_CodeAttributeDecoder$refs;
typedef struct _jc_jas_CodeAttributeDecoder$nonrefs	_jc_jas_CodeAttributeDecoder$nonrefs;
typedef struct _jc_jas_CodeAttributeDecoder$object	_jc_jas_CodeAttributeDecoder$object;

typedef const struct _jc_jas_CodeAttributeDecoder$vmethods	_jc_jas_CodeAttributeDecoder$vmethods;
typedef const struct _jc_jas_CodeAttributeDecoder$vtable	_jc_jas_CodeAttributeDecoder$vtable;
typedef const struct _jc_jas_CodeAttributeDecoder$vtype	_jc_jas_CodeAttributeDecoder$vtype;

// Constructors
extern void _jc_jas_CodeAttributeDecoder$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_jas_CodeAttributeDecoder$object *);

// Static methods
extern _jc_byte_array *_jc_jas_CodeAttributeDecoder$method$decode$842483d88e34cc59(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_util_Hashtable$object *);

// Virtual methods structure
struct _jc_jas_CodeAttributeDecoder$vmethods {
};

// Vtable
struct _jc_jas_CodeAttributeDecoder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_CodeAttributeDecoder$vmethods	jas_CodeAttributeDecoder;
};

// Vtype
struct _jc_jas_CodeAttributeDecoder$vtype {
	_jc_type			type;
	_jc_jas_CodeAttributeDecoder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_CodeAttributeDecoder$sub_refs {
};

// Reference instance fields (object)
struct _jc_jas_CodeAttributeDecoder$refs {
    _jc_jas_CodeAttributeDecoder$sub_refs	jas_CodeAttributeDecoder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_CodeAttributeDecoder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jas_CodeAttributeDecoder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_CodeAttributeDecoder$sub_nonrefs	jas_CodeAttributeDecoder;
};

// Object instance structure
struct _jc_jas_CodeAttributeDecoder$object {
	_jc_jas_CodeAttributeDecoder$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_CodeAttributeDecoder$vtype	*vtype;
	_jc_jas_CodeAttributeDecoder$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_CodeAttributeDecoder$vtype _jc_jas_CodeAttributeDecoder$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_CodeAttributeDecoder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_CodeAttributeDecoder$class_object;

#endif	/* _JC_jas_CodeAttributeDecoder_H_ */

==> jc-1.4.6.tar.gz: jas/CodeAttributeDecoder.h <==
// class jas.CodeAttributeDecoder

// class file dependencies
// @dep_class 1e8dee4cc3706ae3 jas_CodeAttributeDecoder
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_jas_CodeAttributeDecoder_H_
#define _JC_jas_CodeAttributeDecoder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Hashtable$object;

// Typedefs
typedef struct _jc_jas_CodeAttributeDecoder$sub_refs	_jc_jas_CodeAttributeDecoder$sub_refs;
typedef struct _jc_jas_CodeAttributeDecoder$sub_nonrefs	_jc_jas_CodeAttributeDecoder$sub_nonrefs;
typedef struct _jc_jas_CodeAttributeDecoder$refs	_jc_jas_CodeAttributeDecoder$refs;
typedef struct _jc_jas_CodeAttributeDecoder$nonrefs	_jc_jas_CodeAttributeDecoder$nonrefs;
typedef struct _jc_jas_CodeAttributeDecoder$object	_jc_jas_CodeAttributeDecoder$object;

typedef const struct _jc_jas_CodeAttributeDecoder$vmethods	_jc_jas_CodeAttributeDecoder$vmethods;
typedef const struct _jc_jas_CodeAttributeDecoder$vtable	_jc_jas_CodeAttributeDecoder$vtable;
typedef const struct _jc_jas_CodeAttributeDecoder$vtype	_jc_jas_CodeAttributeDecoder$vtype;

// Constructors
extern void _jc_jas_CodeAttributeDecoder$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_jas_CodeAttributeDecoder$object *) _JC_JCNI_ATTR;

// Static methods
extern _jc_byte_array *_jc_jas_CodeAttributeDecoder$method$decode$842483d88e34cc59(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_util_Hashtable$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_jas_CodeAttributeDecoder$vmethods {
};

// Vtable
struct _jc_jas_CodeAttributeDecoder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_CodeAttributeDecoder$vmethods	jas_CodeAttributeDecoder;
};

// Vtype
struct _jc_jas_CodeAttributeDecoder$vtype {
	_jc_type			type;
	_jc_jas_CodeAttributeDecoder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_CodeAttributeDecoder$sub_refs {
};

// Reference instance fields (object)
struct _jc_jas_CodeAttributeDecoder$refs {
    _jc_jas_CodeAttributeDecoder$sub_refs	jas_CodeAttributeDecoder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_CodeAttributeDecoder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jas_CodeAttributeDecoder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_CodeAttributeDecoder$sub_nonrefs	jas_CodeAttributeDecoder;
};

// Object instance structure
struct _jc_jas_CodeAttributeDecoder$object {
	_jc_jas_CodeAttributeDecoder$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_CodeAttributeDecoder$vtype	*vtype;
	_jc_jas_CodeAttributeDecoder$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_CodeAttributeDecoder$vtype _jc_jas_CodeAttributeDecoder$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_CodeAttributeDecoder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_CodeAttributeDecoder$class_object;

#endif	/* _JC_jas_CodeAttributeDecoder_H_ */
